==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebPaneCloseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneCloseEventArgsDescription } from "./WebPaneCloseEventArgsDescription";
/**
 * @hidden
 */
var WebPaneCloseEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneCloseEventArgsDescriptionMetadata, _super);
    function WebPaneCloseEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneCloseEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneCloseEventArgsDescriptionMetadata.a == null) {
            WebPaneCloseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneCloseEventArgsDescriptionMetadata.c(WebPaneCloseEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebPaneCloseEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebPaneCloseEventArgsDescriptionMetadata.a);
        WebPaneCloseEventArgsDescriptionMetadata.d(a);
    };
    WebPaneCloseEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneCloseEventArgs");
        a.item("Detail", "ExportedType:WebPaneCloseEventArgs");
    };
    WebPaneCloseEventArgsDescriptionMetadata.d = function (a) {
        WebPaneCloseEventArgsDescriptionMetadata.b(a);
        a.u("WebPaneCloseEventArgs", function () { return new WebPaneCloseEventArgsDescription(); });
        a.t("WebPaneCloseEventArgs", WebPaneCloseEventArgsDescriptionMetadata.a);
    };
    WebPaneCloseEventArgsDescriptionMetadata.$t = markType(WebPaneCloseEventArgsDescriptionMetadata, 'WebPaneCloseEventArgsDescriptionMetadata');
    WebPaneCloseEventArgsDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDescriptionMetadata;
}(Base));
export { WebPaneCloseEventArgsDescriptionMetadata };

==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/WebPaneCloseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneCloseEventArgsDescription } from "./WebPaneCloseEventArgsDescription";
/**
 * @hidden
 */
var WebPaneCloseEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneCloseEventArgsDescriptionMetadata, _super);
    function WebPaneCloseEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneCloseEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneCloseEventArgsDescriptionMetadata.a == null) {
            WebPaneCloseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneCloseEventArgsDescriptionMetadata.c(WebPaneCloseEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebPaneCloseEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebPaneCloseEventArgsDescriptionMetadata.a);
        WebDockManagerPaneDescriptionMetadata.d(a);
    };
    WebPaneCloseEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneCloseEventArgs");
        a.item("SourcePane", "ExportedType:WebDockManagerPane");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
    };
    WebPaneCloseEventArgsDescriptionMetadata.d = function (a) {
        WebPaneCloseEventArgsDescriptionMetadata.b(a);
        a.u("WebPaneCloseEventArgs", function () { return new WebPaneCloseEventArgsDescription(); });
        a.t("WebPaneCloseEventArgs", WebPaneCloseEventArgsDescriptionMetadata.a);
    };
    WebPaneCloseEventArgsDescriptionMetadata.$t = markType(WebPaneCloseEventArgsDescriptionMetadata, 'WebPaneCloseEventArgsDescriptionMetadata');
    WebPaneCloseEventArgsDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDescriptionMetadata;
}(Base));
export { WebPaneCloseEventArgsDescriptionMetadata };
